/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
 
//*****************************************************************************
// TIDM-CAPTIVATE-64-BUTTON_IllegalTouchDemo.c
//
//! \version 1.00.00.00
//
//*****************************************************************************

#include <TIDM-CAPTIVATE-64-BUTTON_IllegalTouchDemo.h>
#include "CAPT_UserConfig.h"
#include "CAPT_BSP.h"
#include "driverlib.h"

//**********************************************************************************
// Globals
//**********************************************************************************

//! \brief Masks touches on keypad while true
//!
static bool Demo_keypadTouchMaskActive = false;

//**********************************************************************************
// Function Prototypes
//**********************************************************************************

//! \brief Configures Timer A0 to delay recording of touches
//!
static void Demo_startKeypadTouchMaskDelay(void);

//! \brief Keypad handler that determines if touch is valid
//!
void Demo_64ButtonKeypadHandler(tSensor* pSensor);

void Demo_registerKeypadCallback(void)
{
	MAP_CAPT_registerCallback(&keypad64Button, &Demo_64ButtonKeypadHandler);
}

void Demo_64ButtonKeypadHandler(tSensor* pSensor)
{
	uint8_t cycle, element, touchCount = 0, detectCount = 0;

	if(pSensor->bSensorTouch)
	{
		// Count up number of keypad buttons in touch state
		// or detect state
		for(cycle = 0; cycle < pSensor->ui8NrOfCycles; cycle++)
		{
			for(element = 0; element < pSensor->pCycle[cycle]->ui8NrOfElements; element++)
			{
				if(pSensor->pCycle[cycle]->pElements[element]->bTouch)
				{
					touchCount++;
				}
				else if (pSensor->pCycle[cycle]->pElements[element]->bDetect)
				{
					detectCount++;
				}
			}
		}

		// Determine if a valid touch occured
		if(touchCount > DEMO_KEYPAD_MAX_TOUCH_ALLOWED || detectCount > DEMO_KEYPAD_MAX_DETECT_ALLOWED)
		{
			// Invalid touch: LED2 on
			LED1_OFF;
			LED2_ON;

			// Ignore valid touches for set delay
			Demo_keypadTouchMaskActive = true;
			Demo_startKeypadTouchMaskDelay();
		}
		else
		{
			if(!Demo_keypadTouchMaskActive)
			{
				// Valid touch: LED1 on
				LED1_ON;
				LED2_OFF;
			}
		}
	}
	else
	{
		if(!Demo_keypadTouchMaskActive)
		{
			// No touch detected: LED1 & LED2 off
			LED1_OFF;
			LED2_OFF;
		}
	}
}

void Demo_startKeypadTouchMaskDelay(void)
{
	// Stop Timer A0 and clear interrupt
	Timer_A_stop(TIMER_A0_BASE);
	Timer_A_clearTimerInterrupt(TIMER_A0_BASE);

	//Start timer in continuous mode sourced by ACLK
	Timer_A_initUpModeParam param = {0};
	param.clockSource = TIMER_A_CLOCKSOURCE_ACLK;
	param.clockSourceDivider = TIMER_A_CLOCKSOURCE_DIVIDER_1;
	param.timerPeriod = DEMO_KEYPAD_TOUCH_MASK_DELAY;
	param.captureCompareInterruptEnable_CCR0_CCIE = TIMER_A_CCIE_CCR0_INTERRUPT_ENABLE;
	param.timerClear = TIMER_A_DO_CLEAR;
	param.startTimer = true;
	Timer_A_initUpMode(TIMER_A0_BASE, &param);
}

//******************************************************************************
//
//This is the TIMER0_A3 interrupt vector service routine.
//
//******************************************************************************
#if defined(__TI_COMPILER_VERSION__) || defined(__IAR_SYSTEMS_ICC__)
#pragma vector=TIMER0_A0_VECTOR
__interrupt
#elif defined(__GNUC__)
__attribute__((interrupt(TIMER0_A0_VECTOR)))
#endif
void TIMER0_A0_ISR(void)
{
	// Stop timer and clear touch mask flag
	Timer_A_stop(TIMER_A0_BASE);
    Demo_keypadTouchMaskActive = false;
}
