/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//*****************************************************************************
// Development main.c for MSP430FR26xx_25xx
//
// This starter application initializes the CapTIvate touch library
// for the touch panel specified by CAPT_UserConfig.c/.h via a call to
// CAPT_appStart(), which initializes and calibrates all sensors in the
// application, and starts the CapTIvate interval timer.
//
// Then, the capacitive touch interface is driven by calling the CapTIvate
// application handler, CAPT_appHandler().  The application handler manages
// whether the user interface (UI) is running in full active scan mode, or
// in a low-power wake-on-proximity mode.
//
// The CapTIvate application handler will return true if proximity was
// detected on any of the sensors in the application. If POWER_TESTING is
// not defined, the number of buttons in a touch state is counted following the 
// application handler. If a single touch is detected, LED1 will turn on. If 
// more than one touch is detected, LED1 and LED2 will turn on.
//
// \version 1.01.01.00
// Released on Thu, Oct 15, 2015 12:27:24 AM
//
//*****************************************************************************

//*****************************************************************************
//! \addtogroup Low_Power_Main
//! @{
//*****************************************************************************

#include <msp430.h>                      // Generic MSP430 Device Include
#include "driverlib.h"                   // MSPWare Driver Library
#include "captivate.h"                   // CapTIvate Touch Software Library
#include "CAPT_App.h"                    // CapTIvate Application Code
#include "CAPT_BSP.h"                    // CapTIvate EVM Board Support Package

//*****************************************************************************
//
//! \brief Defines the index in the sensor list of the keypad sensor
//
//*****************************************************************************
#define KEYPAD_SENSOR 0

//*****************************************************************************
//
//! \brief Eliminates background application code from build when defined
//
//*****************************************************************************
//#define POWER_TESTING

void main(void)
{
	//
	// Initialize the MCU
	// BSP_configureMCU() sets up the device IO and clocking
	// The global interrupt enable is set to allow peripherals
	// to wake the MCU.
	//
	WDT_A_hold(WDT_A_BASE);
	BSP_configureMCU();
	__bis_SR_register(GIE);

	//
	// Start the CapTIvate application
	//
	CAPT_appStart();

	//
	// Background Loop
	//
	while(1)
	{
		//
		// Run the captivate application handler.
		//
		CAPT_appHandler();

#ifndef POWER_TESTING
		//
		// This is a great place to add in any
		// background application code.
		//
		if(g_uiApp.pSensorList[0]->bSensorTouch)
		{
			uint8_t cycle, element, touchCount = 0;

			for(cycle = 0; cycle < g_uiApp.pSensorList[KEYPAD_SENSOR]->ui8NrOfCycles; cycle++)
			{
				for(element = 0; element < g_uiApp.pSensorList[KEYPAD_SENSOR]->pCycle[cycle]->ui8NrOfElements; element++)
				{
					if(g_uiApp.pSensorList[KEYPAD_SENSOR]->pCycle[cycle]->pElements[element]->bTouch)
					{
						touchCount++;
					}
				}
			}

			LED1_ON;
			if(touchCount > 1)
			{
				LED2_ON;
			}
			else
			{
				LED2_OFF;
			}
		}
		else
		{
			LED1_OFF;
			LED2_OFF;
		}

#endif
		//
		// End of background loop iteration
		// Go to sleep if there is nothing left to do
		//
		CAPT_appSleep();
		
	} // End background loop
} // End main()

//*****************************************************************************
//! Close the doxygen group
//! @}
//*****************************************************************************
